<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>View</name>
    <message>
        <location filename="../View.js" line="+64"/>
        <source>View Tools</source>
        <translation>Nástroje zobrazení</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show view tools</source>
        <translation>Zobrazit nástroje zobrazení</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;View</source>
        <translation>&amp;Zobrazit</translation>
    </message>
</context>
</TS>
